@@ -19,7 +19,8 @@ from qingcloud.misc.json_tool import json_load
 from qingcloud.misc.utils import filter_out_none
 
 import constants as const
-from consolidator import RequestChecker
+from .consolidator import RequestChecker
+from .monitor import MonitorProcessor
 
 
 class APIConnection(HttpConnection):
@@ -1799,19 +1800,20 @@ class APIConnection(HttpConnection):
                                   step,
                                   start_time,
                                   end_time,
+                                  decompress=False,
                                   **ignore):
         """ Get resource monitoring data.
 
             @param resource: the ID of resource, can be instance_id, volume_id, eip_id or router_id.
             @param meters: list of metering types you want to get.
                            If resource is instance, meter can be "cpu", "disk-os", "memory",
-                           "'disk-%s' % attached_volume_id", "'if-%s' % vxnet_mac_address".
-                           If resource is volume, meter should be "'disk-%s' % volume_id".
+                           "disk-%s" % attached_volume_id, "if-%s" % vxnet_mac_address.
+                           If resource is volume, meter should be "disk-%s" % volume_id.
                            If resource is eip, meter should be "traffic".
-                           If resource is router, meter should be "vxnet-0".
+                           If resource is router, meter can be "vxnet-0" and joint vxnet ID.
             @param step: The metering time step, valid steps: "5m", "15m", "30m", "1h", "2h", "1d".
-            @param start_time: the starting time stamp. In the format YYYY-MM-DDThh:mm:ssZ.
-            @param end_time: the ending time stamp. In the format YYYY-MM-DDThh:mm:ssZ.
+            @param start_time: the starting UTC time, in the format YYYY-MM-DDThh:mm:ssZ.
+            @param end_time: the ending UTC time, in the format YYYY-MM-DDThh:mm:ssZ.
         """
         action = const.ACTION_GET_MONITOR
         valid_keys = ['resource', 'meters', 'step', 'start_time', 'end_time']
@@ -1819,25 +1821,31 @@ class APIConnection(HttpConnection):
         if not self.req_checker.check_params(body,
                 required_params=['resource', 'meters', 'step', 'start_time', 'end_time'],
                 integer_params=[],
+                datetime_params=['start_time', 'end_time'],
                 list_params=['meters']
                 ):
             return None
 
-        return self.send_request(action, body)
+        resp = self.send_request(action, body)
+        if resp and resp.get('meter_set') and decompress:
+            p = MonitorProcessor(resp['meter_set'], start_time, end_time, step)
+            resp['meter_set'] = p.decompress_monitoring_data()
+        return resp
 
     def get_loadbalancer_monitoring_data(self, resource,
                                                meters,
                                                step,
                                                start_time,
                                                end_time,
+                                               decompress=False,
                                                **ignore):
         """ Get load balancer monitoring data.
 
             @param resource: the ID of resource, can be loadbalancer_id, listener_id or backend_id.
             @param meters: list of metering types you want to get, valid values: request, traffic.
             @param step: The metering time step, valid steps: "5m", "15m", "30m", "1h", "2h", "1d".
-            @param start_time: the starting time stamp. In the format YYYY-MM-DDThh:mm:ssZ.
-            @param end_time: the ending time stamp. In the format YYYY-MM-DDThh:mm:ssZ.
+            @param start_time: the starting UTC time, in the format YYYY-MM-DDThh:mm:ssZ.
+            @param end_time: the ending UTC time, in the format YYYY-MM-DDThh:mm:ssZ.
         """
         action = const.ACTION_GET_LOADBALANCER_MONITOR
         valid_keys = ['resource', 'meters', 'step', 'start_time', 'end_time']
@@ -1845,8 +1853,13 @@ class APIConnection(HttpConnection):
         if not self.req_checker.check_params(body,
                 required_params=['resource', 'meters', 'step', 'start_time', 'end_time'],
                 integer_params=[],
+                datetime_params=['start_time', 'end_time'],
                 list_params=['meters']
                 ):
             return None
 
-        return self.send_request(action, body)
+        resp = self.send_request(action, body)
+        if resp and resp.get('meter_set') and decompress:
+            p = MonitorProcessor(resp['meter_set'], start_time, end_time, step)
+            resp['meter_set'] = p.decompress_lb_monitoring_data()
+        return resp
